use crate::controllers::HttpResult;
use crate::extractors::account_extractor::AccountInPath;
use crate::extractors::auth_extractor::AuthExtractor;
use crate::services::movements_service;
use crate::services::movements_service::UpdateMovementQuery;
use actix_web::{HttpResponse, web};

/// Create a new movement
pub async fn create(auth: AuthExtractor, req: web::Json<UpdateMovementQuery>) -> HttpResult {
    if let Some(err) = req.check_error(auth.user_id()).await? {
        return Ok(HttpResponse::BadRequest().json(err));
    }

    movements_service::create(&req).await?;

    Ok(HttpResponse::Created().finish())
}

/// Get the list of movements of an account
pub async fn get_list_of_account(account_id: AccountInPath) -> HttpResult {
    Ok(HttpResponse::Ok()
        .json(movements_service::get_list_account(account_id.as_ref().id()).await?))
}
